@@ -12,7 +12,7 @@ Usage::
     session_client: EC2InstanceConnectClient = session.client("ec2-instance-connect")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Any, Dict, TYPE_CHECKING
+from typing import Any, Dict, TYPE_CHECKING, Type
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_ec2_instance_connect.type_defs import SendSSHPublicKeyResponseTypeDef
 
@@ -21,12 +21,12 @@ __all__ = ("EC2InstanceConnectClient",)
 
 
 class Exceptions:
-    AuthException: Boto3ClientError
-    ClientError: Boto3ClientError
-    EC2InstanceNotFoundException: Boto3ClientError
-    InvalidArgsException: Boto3ClientError
-    ServiceException: Boto3ClientError
-    ThrottlingException: Boto3ClientError
+    AuthException: Type[Boto3ClientError]
+    ClientError: Type[Boto3ClientError]
+    EC2InstanceNotFoundException: Type[Boto3ClientError]
+    InvalidArgsException: Type[Boto3ClientError]
+    ServiceException: Type[Boto3ClientError]
+    ThrottlingException: Type[Boto3ClientError]
 
 
 class EC2InstanceConnectClient:
